@@ -40,7 +40,7 @@ class News:
                     if self._is_new(str(child.text)):
                         if first_news:
                             print_stdout(
-                                '\n' + color_line(_('There are news from archlinux.org!'), 9) + '\n'
+                                '\n' + color_line(_('There is news from archlinux.org!'), 9) + '\n'
                             )
                         self._print_one_entry(news_entry)
                         # news are in inverse chronological order (newest first).
